@@ -1,4 +1,4 @@
-from typing import List, Optional, Union
+from typing import Dict, List, Optional, Union
 
 from pydantic import BaseModel, Field, validator
 
@@ -9,25 +9,109 @@ from .errors import ErrorCodeEnum, LegacyErrorCodeEnum
 class RcsSMSBody(BaseModel):
     title: Optional[str] = Field(max_length=30)
     description: str = Field(max_length=100)
-    # TODO: media:
+    media: Optional[str]
 
 
 class RcsLMSBody(BaseModel):
     title: Optional[str] = Field(max_length=30)
     description: str = Field(max_length=1300)
-    # TODO: media:
+    media: Optional[str]
 
 
 class RcsMMSBody(BaseModel):
     title: Optional[str] = Field(max_length=30)
     description: str = Field(max_length=1300)
-    # TODO: media:
+    media: Optional[str]
 
 
 class RcsCHATBody(BaseModel):
     title: Optional[str] = Field(max_length=30)
     description: str = Field(max_length=1300)
-    # TODO: media:
+    media: Optional[str]
+
+
+class RcsSMSCarouselBody(BaseModel):
+    title1: Optional[str] = Field(max_length=30)
+    description1: str = Field(max_length=100)
+    media1: Optional[str]
+    title2: Optional[str] = Field(max_length=30)
+    description2: Optional[str] = Field(max_length=100)
+    media2: Optional[str]
+    title3: Optional[str] = Field(max_length=30)
+    description3: Optional[str] = Field(max_length=100)
+    media3: Optional[str]
+    title4: Optional[str] = Field(max_length=30)
+    description4: Optional[str] = Field(max_length=100)
+    media4: Optional[str]
+    title5: Optional[str] = Field(max_length=30)
+    description5: Optional[str] = Field(max_length=100)
+    media5: Optional[str]
+    title6: Optional[str] = Field(max_length=30)
+    description6: Optional[str] = Field(max_length=100)
+    media6: Optional[str]
+
+
+class RcsLMSCarouselBody(BaseModel):
+    title1: Optional[str] = Field(max_length=30)
+    description1: str = Field(max_length=100)
+    media1: Optional[str]
+    title2: Optional[str] = Field(max_length=30)
+    description2: Optional[str] = Field(max_length=100)
+    media2: Optional[str]
+    title3: Optional[str] = Field(max_length=30)
+    description3: Optional[str] = Field(max_length=100)
+    media3: Optional[str]
+    title4: Optional[str] = Field(max_length=30)
+    description4: Optional[str] = Field(max_length=100)
+    media4: Optional[str]
+    title5: Optional[str] = Field(max_length=30)
+    description5: Optional[str] = Field(max_length=100)
+    media5: Optional[str]
+    title6: Optional[str] = Field(max_length=30)
+    description6: Optional[str] = Field(max_length=100)
+    media6: Optional[str]
+
+
+class RcsMMSCarouselBody(BaseModel):
+    title1: Optional[str] = Field(max_length=30)
+    description1: str = Field(max_length=100)
+    media1: Optional[str]
+    title2: Optional[str] = Field(max_length=30)
+    description2: Optional[str] = Field(max_length=100)
+    media2: Optional[str]
+    title3: Optional[str] = Field(max_length=30)
+    description3: Optional[str] = Field(max_length=100)
+    media3: Optional[str]
+    title4: Optional[str] = Field(max_length=30)
+    description4: Optional[str] = Field(max_length=100)
+    media4: Optional[str]
+    title5: Optional[str] = Field(max_length=30)
+    description5: Optional[str] = Field(max_length=100)
+    media5: Optional[str]
+    title6: Optional[str] = Field(max_length=30)
+    description6: Optional[str] = Field(max_length=100)
+    media6: Optional[str]
+
+
+class RcsCHATCarouselBody(BaseModel):
+    title1: Optional[str] = Field(max_length=30)
+    description1: str = Field(max_length=100)
+    media1: Optional[str]
+    title2: Optional[str] = Field(max_length=30)
+    description2: Optional[str] = Field(max_length=100)
+    media2: Optional[str]
+    title3: Optional[str] = Field(max_length=30)
+    description3: Optional[str] = Field(max_length=100)
+    media3: Optional[str]
+    title4: Optional[str] = Field(max_length=30)
+    description4: Optional[str] = Field(max_length=100)
+    media4: Optional[str]
+    title5: Optional[str] = Field(max_length=30)
+    description5: Optional[str] = Field(max_length=100)
+    media5: Optional[str]
+    title6: Optional[str] = Field(max_length=30)
+    description6: Optional[str] = Field(max_length=100)
+    media6: Optional[str]
 
 
 class RcsTMPLBody(BaseModel):
@@ -92,7 +176,8 @@ class MapActionInfo(BaseModel):
     미리 지정된 위치를 보여주거나 사용자의 현재 위치를 서버로 전송 할 수 있습니다.
     """
 
-    showLocation: ShowLocationInfo
+    showLocation: Optional[ShowLocationInfo]
+    requestLocationPush: Optional[Dict]
 
 
 class CalendarActionInfo(BaseModel):
@@ -177,7 +262,7 @@ class RcsInfo(BaseModel):
     * Agency ID는 "Rcs Biz Center - 브랜드 운영관리" 에서 기업의 브랜드가 대행사 권한을 부여한 대행사의 ID
     Agency ID가 "ktbizrcs" 가 아닌 경우 필수 입력 필요.
     """
-    messagebaseId: enums.MessageEnum
+    messagebaseId: Union[enums.MessageEnum, enums.RCSMessageEnum]
     serviceType: enums.ServiceTypeEnum
     expiryOption: Optional[enums.ExpiryOptionEnum]
     """
@@ -226,7 +311,17 @@ class RcsInfo(BaseModel):
     - false: 복사 허용 하지 않음
     """
 
-    body: Union[RcsSMSBody, RcsLMSBody, RcsMMSBody, RcsCHATBody, RcsTMPLBody]
+    body: Union[
+        RcsSMSBody,
+        RcsLMSBody,
+        RcsMMSBody,
+        RcsCHATBody,
+        RcsTMPLBody,
+        RcsSMSCarouselBody,
+        RcsLMSCarouselBody,
+        RcsMMSCarouselBody,
+        RcsCHATCarouselBody,
+    ]
     """
     # body
     메시지베이스에서 치환할 파라미터의 정보를 담은 json object.
@@ -362,6 +457,32 @@ class ResponseInfo(BaseModel):
     data: dict
 
 
+class TextMessageInfo(BaseModel):
+    textMessage: str
+
+
+class FileMessage(BaseModel):
+    downloadField: str
+    mimeType: str
+    size: str
+
+
+class FileMessageInfo(BaseModel):
+    fileMessage: str
+
+
+class GeolocationPushMessage(BaseModel):
+    label: str
+    timestamp: str
+    timeOffset: str
+    pos: str
+    radius: int
+
+
+class UserLocationInfo(BaseModel):
+    geolocationPushMessage: GeolocationPushMessage
+
+
 class MessageInfo(BaseModel):
     replyId: str = Field(max_length=40)
     eventType: enums.EventTypeEnum
@@ -379,7 +500,7 @@ class MessageInfo(BaseModel):
     postBackId: Optional[str] = Field(max_length=40)
     postBackData: Optional[str] = Field(max_length=2048)
     displayText: Optional[str] = Field(max_length=200)
-    messageBody: Optional[str] = Field(max_length=10240)
+    messageBody: Union[TextMessageInfo, UserLocationInfo, FileMessageInfo, None]
     """
     eventType이message인 경우에만 설정
     - 텍스트 메시지의 경우 샘플
